@@ -48,7 +48,7 @@ class VerbExtensionPoint:
         raise NotImplementedError()
 
 
-def get_verb_extensions():
+def get_verb_extensions(*, group_name=None):
     """
     Get the available verb extensions.
 
@@ -56,7 +56,9 @@ def get_verb_extensions():
 
     :rtype: OrderedDict
     """
-    extensions = instantiate_extensions(__name__)
+    if group_name is None:
+        group_name = __name__
+    extensions = instantiate_extensions(group_name)
     for name, extension in extensions.items():
         extension.VERB_NAME = name
     return order_extensions_by_name(extensions)
